@@ -10,6 +10,7 @@
 #include <QtGlobal>
 
 #include <QColorSpace>
+#include <QLoggingCategory>
 
 #include "avif_p.h"
 #include "microexif_p.h"
@@ -17,6 +18,12 @@
 
 #include <cfloat>
 
+#ifdef QT_DEBUG
+Q_LOGGING_CATEGORY(LOG_AVIFPLUGIN, "kf.imageformats.plugins.avif", QtDebugMsg)
+#else
+Q_LOGGING_CATEGORY(LOG_AVIFPLUGIN, "kf.imageformats.plugins.avif", QtWarningMsg)
+#endif
+
 /*
 Quality range - compression/subsampling
 100 - lossless RGB compression
@@ -168,7 +175,7 @@ bool QAVIFHandler::ensureDecoder()
 
     decodeResult = avifDecoderSetIOMemory(m_decoder, m_rawAvifData.data, m_rawAvifData.size);
     if (decodeResult != AVIF_RESULT_OK) {
-        qWarning("ERROR: avifDecoderSetIOMemory failed: %s", avifResultToString(decodeResult));
+        qCWarning(LOG_AVIFPLUGIN, "ERROR: avifDecoderSetIOMemory failed: %s", avifResultToString(decodeResult));
 
         avifDecoderDestroy(m_decoder);
         m_decoder = nullptr;
@@ -178,7 +185,7 @@ bool QAVIFHandler::ensureDecoder()
 
     decodeResult = avifDecoderParse(m_decoder);
     if (decodeResult != AVIF_RESULT_OK) {
-        qWarning("ERROR: Failed to parse input: %s", avifResultToString(decodeResult));
+        qCWarning(LOG_AVIFPLUGIN, "ERROR: Failed to parse input: %s", avifResultToString(decodeResult));
 
         avifDecoderDestroy(m_decoder);
         m_decoder = nullptr;
@@ -190,19 +197,19 @@ bool QAVIFHandler::ensureDecoder()
     m_container_height = m_decoder->image->height;
 
     if ((m_container_width > 65535) || (m_container_height > 65535)) {
-        qWarning("AVIF image (%dx%d) is too large!", m_container_width, m_container_height);
+        qCWarning(LOG_AVIFPLUGIN, "AVIF image (%dx%d) is too large!", m_container_width, m_container_height);
         m_parseState = ParseAvifError;
         return false;
     }
 
     if ((m_container_width == 0) || (m_container_height == 0)) {
-        qWarning("Empty image, nothing to decode");
+        qCWarning(LOG_AVIFPLUGIN, "Empty image, nothing to decode");
         m_parseState = ParseAvifError;
         return false;
     }
 
     if (m_container_width > ((16384 * 16384) / m_container_height)) {
-        qWarning("AVIF image (%dx%d) has more than 256 megapixels!", m_container_width, m_container_height);
+        qCWarning(LOG_AVIFPLUGIN, "AVIF image (%dx%d) has more than 256 megapixels!", m_container_width, m_container_height);
         m_parseState = ParseAvifError;
         return false;
     }
@@ -276,7 +283,7 @@ bool QAVIFHandler::decode_one_frame()
 
     QImage result = imageAlloc(m_decoder->image->width, m_decoder->image->height, resultformat);
     if (result.isNull()) {
-        qWarning("Memory cannot be allocated");
+        qCWarning(LOG_AVIFPLUGIN, "Memory cannot be allocated");
         return false;
     }
 
@@ -285,12 +292,10 @@ bool QAVIFHandler::decode_one_frame()
         const QByteArray icc_data(reinterpret_cast<const char *>(m_decoder->image->icc.data), m_decoder->image->icc.size);
         colorspace = QColorSpace::fromIccProfile(icc_data);
         if (!colorspace.isValid()) {
-            qWarning("AVIF image has Qt-unsupported or invalid ICC profile!");
-        }
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
-        else {
+            qCWarning(LOG_AVIFPLUGIN, "AVIF image has Qt-unsupported or invalid ICC profile!");
+        } else {
             if (colorspace.colorModel() == QColorSpace::ColorModel::Cmyk) {
-                qWarning("CMYK ICC profile is not extected for AVIF, discarding the ICCprofile!");
+                qCWarning(LOG_AVIFPLUGIN, "CMYK ICC profile is not extected for AVIF, discarding the ICCprofile!");
                 colorspace = QColorSpace();
             } else if (colorspace.colorModel() == QColorSpace::ColorModel::Rgb && loadgray) {
                 // Input is GRAY but ICC is RGB, we will return RGB image
@@ -314,11 +319,10 @@ bool QAVIFHandler::decode_one_frame()
                 }
                 colorspace = QColorSpace(gray_whitePoint, redP, greenP, blueP, trc_new, gamma_new);
                 if (!colorspace.isValid()) {
-                    qWarning("AVIF plugin created invalid QColorSpace!");
+                    qCWarning(LOG_AVIFPLUGIN, "AVIF plugin created invalid QColorSpace!");
                 }
             }
         }
-#endif
     } else {
         float prim[8] = {0.64f, 0.33f, 0.3f, 0.6f, 0.15f, 0.06f, 0.3127f, 0.329f};
         // outPrimaries: rX, rY, gX, gY, bX, bY, wX, wY
@@ -353,16 +357,14 @@ bool QAVIFHandler::decode_one_frame()
         case 13:
             q_trc = QColorSpace::TransferFunction::SRgb;
             break;
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
         case 16: /* AVIF_TRANSFER_CHARACTERISTICS_PQ */
             q_trc = QColorSpace::TransferFunction::St2084;
             break;
         case 18: /* AVIF_TRANSFER_CHARACTERISTICS_HLG */
             q_trc = QColorSpace::TransferFunction::Hlg;
             break;
-#endif
         default:
-            qWarning("CICP colorPrimaries: %d, transferCharacteristics: %d\nThe colorspace is unsupported by this plug-in yet.",
+            qCWarning(LOG_AVIFPLUGIN, "CICP colorPrimaries: %d, transferCharacteristics: %d\nThe colorspace is unsupported by this plug-in yet.",
                      m_decoder->image->colorPrimaries,
                      m_decoder->image->transferCharacteristics);
             q_trc = QColorSpace::TransferFunction::SRgb;
@@ -370,11 +372,9 @@ bool QAVIFHandler::decode_one_frame()
         }
 
         if (q_trc != QColorSpace::TransferFunction::Custom) { // we create new colorspace using Qt
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
             if (loadgray) {
                 colorspace = QColorSpace(whitePoint, q_trc, q_trc_gamma);
             } else {
-#endif
                 switch (m_decoder->image->colorPrimaries) {
                 /* AVIF_COLOR_PRIMARIES_BT709 */
                 case 0:
@@ -390,13 +390,11 @@ bool QAVIFHandler::decode_one_frame()
                     colorspace = QColorSpace(whitePoint, redPoint, greenPoint, bluePoint, q_trc, q_trc_gamma);
                     break;
                 }
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
             }
-#endif
         }
 
         if (!colorspace.isValid()) {
-            qWarning("AVIF plugin created invalid QColorSpace from NCLX/CICP!");
+            qCWarning(LOG_AVIFPLUGIN, "AVIF plugin created invalid QColorSpace from NCLX/CICP!");
         }
     }
 
@@ -439,7 +437,7 @@ bool QAVIFHandler::decode_one_frame()
 
     avifResult res = avifImageYUVToRGB(m_decoder->image, &rgb);
     if (res != AVIF_RESULT_OK) {
-        qWarning("ERROR in avifImageYUVToRGB: %s", avifResultToString(res));
+        qCWarning(LOG_AVIFPLUGIN, "ERROR in avifImageYUVToRGB: %s", avifResultToString(res));
         return false;
     }
 
@@ -478,7 +476,7 @@ bool QAVIFHandler::decode_one_frame()
         }
 
         else { // Zero values, we need to avoid 0 divide.
-            qWarning("ERROR: Wrong values in avifCleanApertureBox");
+            qCWarning(LOG_AVIFPLUGIN, "ERROR: Wrong values in avifCleanApertureBox");
         }
     }
 
@@ -556,7 +554,7 @@ static void setMetadata(avifImage *avif, const QImage& image)
 #if AVIF_VERSION >= 1000000
         auto res = avifImageSetMetadataXMP(avif, reinterpret_cast<const uint8_t *>(xmp.constData()), xmp.size());
         if (res != AVIF_RESULT_OK) {
-            qWarning("ERROR in avifImageSetMetadataXMP: %s", avifResultToString(res));
+            qCWarning(LOG_AVIFPLUGIN, "ERROR in avifImageSetMetadataXMP: %s", avifResultToString(res));
         }
 #else
         avifImageSetMetadataXMP(avif, reinterpret_cast<const uint8_t *>(xmp.constData()), xmp.size());
@@ -567,7 +565,7 @@ static void setMetadata(avifImage *avif, const QImage& image)
 #if AVIF_VERSION >= 1000000
         auto res = avifImageSetMetadataExif(avif, reinterpret_cast<const uint8_t *>(exif.constData()), exif.size());
         if (res != AVIF_RESULT_OK) {
-            qWarning("ERROR in avifImageSetMetadataExif: %s", avifResultToString(res));
+            qCWarning(LOG_AVIFPLUGIN, "ERROR in avifImageSetMetadataExif: %s", avifResultToString(res));
         }
 #else
         avifImageSetMetadataExif(avif, reinterpret_cast<const uint8_t *>(exif.constData()), exif.size());
@@ -602,32 +600,32 @@ bool QAVIFHandler::read(QImage *image)
 bool QAVIFHandler::write(const QImage &image)
 {
     if (image.format() == QImage::Format_Invalid) {
-        qWarning("No image data to save!");
+        qCWarning(LOG_AVIFPLUGIN, "No image data to save!");
         return false;
     }
 
     if ((image.width() > 0) && (image.height() > 0)) {
         if ((image.width() > 65535) || (image.height() > 65535)) {
-            qWarning("Image (%dx%d) is too large to save!", image.width(), image.height());
+            qCWarning(LOG_AVIFPLUGIN, "Image (%dx%d) is too large to save!", image.width(), image.height());
             return false;
         }
 
         if (image.width() > ((16384 * 16384) / image.height())) {
-            qWarning("Image (%dx%d) will not be saved because it has more than 256 megapixels!", image.width(), image.height());
+            qCWarning(LOG_AVIFPLUGIN, "Image (%dx%d) will not be saved because it has more than 256 megapixels!", image.width(), image.height());
             return false;
         }
 
         if ((image.width() > 32768) || (image.height() > 32768)) {
-            qWarning("Image (%dx%d) has a dimension above 32768 pixels, saved AVIF may not work in other software!", image.width(), image.height());
+            qCWarning(LOG_AVIFPLUGIN, "Image (%dx%d) has a dimension above 32768 pixels, saved AVIF may not work in other software!", image.width(), image.height());
         }
     } else {
-        qWarning("Image has zero dimension!");
+        qCWarning(LOG_AVIFPLUGIN, "Image has zero dimension!");
         return false;
     }
 
     const char *encoder_name = avifCodecName(AVIF_CODEC_CHOICE_AUTO, AVIF_CODEC_FLAG_CAN_ENCODE);
     if (!encoder_name) {
-        qWarning("Cannot save AVIF images because libavif was built without AV1 encoders!");
+        qCWarning(LOG_AVIFPLUGIN, "Cannot save AVIF images because libavif was built without AV1 encoders!");
         return false;
     }
 
@@ -636,7 +634,7 @@ bool QAVIFHandler::write(const QImage &image)
         if (avifCodecName(AVIF_CODEC_CHOICE_AOM, AVIF_CODEC_FLAG_CAN_ENCODE)) {
             lossless = true;
         } else {
-            qWarning("You are using %s encoder. It is recommended to enable libAOM encoder in libavif to use lossless compression.", encoder_name);
+            qCWarning(LOG_AVIFPLUGIN, "You are using %s encoder. It is recommended to enable libAOM encoder in libavif to use lossless compression.", encoder_name);
         }
     }
 
@@ -718,7 +716,7 @@ bool QAVIFHandler::write(const QImage &image)
 #if AVIF_VERSION >= 110000
         res = avifImageAllocatePlanes(avif, AVIF_PLANES_YUV);
         if (res != AVIF_RESULT_OK) {
-            qWarning("ERROR in avifImageAllocatePlanes: %s", avifResultToString(res));
+            qCWarning(LOG_AVIFPLUGIN, "ERROR in avifImageAllocatePlanes: %s", avifResultToString(res));
             return false;
         }
 #else
@@ -740,14 +738,12 @@ bool QAVIFHandler::write(const QImage &image)
                 /* AVIF_TRANSFER_CHARACTERISTICS_SRGB */
                 avif->transferCharacteristics = (avifTransferCharacteristics)13;
                 break;
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
             case QColorSpace::TransferFunction::St2084:
                 avif->transferCharacteristics = (avifTransferCharacteristics)16;
                 break;
             case QColorSpace::TransferFunction::Hlg:
                 avif->transferCharacteristics = (avifTransferCharacteristics)18;
                 break;
-#endif
             default:
                 /* AVIF_TRANSFER_CHARACTERISTICS_UNSPECIFIED */
                 break;
@@ -792,7 +788,6 @@ bool QAVIFHandler::write(const QImage &image)
             }
         }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
         QImage tmpcolorimage;
         auto cs = image.colorSpace();
         if (cs.isValid() && cs.colorModel() == QColorSpace::ColorModel::Cmyk && image.format() == QImage::Format_CMYK8888) {
@@ -807,9 +802,6 @@ bool QAVIFHandler::write(const QImage &image)
         } else {
             tmpcolorimage = image.convertToFormat(tmpformat);
         }
-#else
-        QImage tmpcolorimage = image.convertToFormat(tmpformat);
-#endif
 
         avifPixelFormat pixel_format = AVIF_PIXEL_FORMAT_YUV420;
         if (m_quality >= KIMG_AVIF_QUALITY_HIGH) {
@@ -869,14 +861,12 @@ bool QAVIFHandler::write(const QImage &image)
                 /* AVIF_TRANSFER_CHARACTERISTICS_SRGB */
                 transfer_to_save = (avifTransferCharacteristics)13;
                 break;
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
             case QColorSpace::TransferFunction::St2084:
                 transfer_to_save = (avifTransferCharacteristics)16;
                 break;
             case QColorSpace::TransferFunction::Hlg:
                 transfer_to_save = (avifTransferCharacteristics)18;
                 break;
-#endif
             default:
                 /* AVIF_TRANSFER_CHARACTERISTICS_UNSPECIFIED */
                 transfer_to_save = (avifTransferCharacteristics)2;
@@ -912,14 +902,12 @@ bool QAVIFHandler::write(const QImage &image)
                         case 5: // AVIF_TRANSFER_CHARACTERISTICS_BT470BG
                             tmpcolorimage.convertToColorSpace(QColorSpace(QColorSpace::Primaries::SRgb, 2.8f));
                             break;
-#if (QT_VERSION >= QT_VERSION_CHECK(6, 8, 0))
                         case 16:
                             tmpcolorimage.convertToColorSpace(QColorSpace(QColorSpace::Primaries::SRgb, QColorSpace::TransferFunction::St2084));
                             break;
                         case 18:
                             tmpcolorimage.convertToColorSpace(QColorSpace(QColorSpace::Primaries::SRgb, QColorSpace::TransferFunction::Hlg));
                             break;
-#endif
                         default: // AVIF_TRANSFER_CHARACTERISTICS_SRGB + any other
                             tmpcolorimage.convertToColorSpace(QColorSpace(QColorSpace::Primaries::SRgb, QColorSpace::TransferFunction::SRgb));
                             transfer_to_save = (avifTransferCharacteristics)13;
@@ -959,7 +947,7 @@ bool QAVIFHandler::write(const QImage &image)
 #if AVIF_VERSION >= 1000000
             res = avifImageSetProfileICC(avif, reinterpret_cast<const uint8_t *>(iccprofile.constData()), iccprofile.size());
             if (res != AVIF_RESULT_OK) {
-                qWarning("ERROR in avifImageSetProfileICC: %s", avifResultToString(res));
+                qCWarning(LOG_AVIFPLUGIN, "ERROR in avifImageSetProfileICC: %s", avifResultToString(res));
                 return false;
             }
 #else
@@ -992,7 +980,7 @@ bool QAVIFHandler::write(const QImage &image)
 
         res = avifImageRGBToYUV(avif, &rgb);
         if (res != AVIF_RESULT_OK) {
-            qWarning("ERROR in avifImageRGBToYUV: %s", avifResultToString(res));
+            qCWarning(LOG_AVIFPLUGIN, "ERROR in avifImageRGBToYUV: %s", avifResultToString(res));
             return false;
         }
     }
@@ -1034,11 +1022,11 @@ bool QAVIFHandler::write(const QImage &image)
         if (status > 0) {
             return true;
         } else if (status == -1) {
-            qWarning("Write error: %s", qUtf8Printable(device()->errorString()));
+            qCWarning(LOG_AVIFPLUGIN, "Write error: %s", qUtf8Printable(device()->errorString()));
             return false;
         }
     } else {
-        qWarning("ERROR: Failed to encode: %s", avifResultToString(res));
+        qCWarning(LOG_AVIFPLUGIN, "ERROR: Failed to encode: %s", avifResultToString(res));
     }
 
     return false;
@@ -1140,7 +1128,7 @@ bool QAVIFHandler::jumpToNextImage()
         if (m_decoder->imageIndex >= m_decoder->imageCount - 1) { // start from beginning
             decodeResult = avifDecoderReset(m_decoder);
             if (decodeResult != AVIF_RESULT_OK) {
-                qWarning("ERROR in avifDecoderReset: %s", avifResultToString(decodeResult));
+                qCWarning(LOG_AVIFPLUGIN, "ERROR in avifDecoderReset: %s", avifResultToString(decodeResult));
                 m_parseState = ParseAvifError;
                 return false;
             }
@@ -1150,13 +1138,13 @@ bool QAVIFHandler::jumpToNextImage()
     decodeResult = avifDecoderNextImage(m_decoder);
 
     if (decodeResult != AVIF_RESULT_OK) {
-        qWarning("ERROR: Failed to decode Next image in sequence: %s", avifResultToString(decodeResult));
+        qCWarning(LOG_AVIFPLUGIN, "ERROR: Failed to decode Next image in sequence: %s", avifResultToString(decodeResult));
         m_parseState = ParseAvifError;
         return false;
     }
 
     if ((m_container_width != m_decoder->image->width) || (m_container_height != m_decoder->image->height)) {
-        qWarning("Decoded image sequence size (%dx%d) do not match first image size (%dx%d)!",
+        qCWarning(LOG_AVIFPLUGIN, "Decoded image sequence size (%dx%d) do not match first image size (%dx%d)!",
                  m_decoder->image->width,
                  m_decoder->image->height,
                  m_container_width,
@@ -1204,13 +1192,13 @@ bool QAVIFHandler::jumpToImage(int imageNumber)
     avifResult decodeResult = avifDecoderNthImage(m_decoder, imageNumber);
 
     if (decodeResult != AVIF_RESULT_OK) {
-        qWarning("ERROR: Failed to decode %d th Image in sequence: %s", imageNumber, avifResultToString(decodeResult));
+        qCWarning(LOG_AVIFPLUGIN, "ERROR: Failed to decode %d th Image in sequence: %s", imageNumber, avifResultToString(decodeResult));
         m_parseState = ParseAvifError;
         return false;
     }
 
     if ((m_container_width != m_decoder->image->width) || (m_container_height != m_decoder->image->height)) {
-        qWarning("Decoded image sequence size (%dx%d) do not match declared container size (%dx%d)!",
+        qCWarning(LOG_AVIFPLUGIN, "Decoded image sequence size (%dx%d) do not match declared container size (%dx%d)!",
                  m_decoder->image->width,
                  m_decoder->image->height,
                  m_container_width,
